Documentation
¶
Index ¶
- Constants
- Variables
- func HandleAppleLogin(oauthConfig *oauth2.Config) http.HandlerFunc
- func HandleGitHubLogin(oauthConfig *oauth2.Config) http.HandlerFunc
- func HandleGoogleLogin(oauthConfig *oauth2.Config) http.HandlerFunc
- func HandleMicrosoftLogin(oauthConfig *oauth2.Config) http.HandlerFunc
- type AppleUser
- type GitHubEmail
- type GitHubUser
- type GoogleUser
- type MicrosoftUser
Constants ¶
const ( // published so the user can find out where his central/operators are later on KindSetupAnnouncement nostr.Kind = 16440 // created at setup time by the user and sent to central/operators KindCentralToken nostr.Kind = 20443 KindOperatorRegistration nostr.Kind = 20444 KindCentralRegistration nostr.Kind = 20445 // used in the communication between central and operators, signed always only by the central key KindConfiguration nostr.Kind = 26430 KindGroupCommit nostr.Kind = 26432 KindEventToBeSigned nostr.Kind = 26433 KindECDHRequest nostr.Kind = 26434 )
Variables ¶
var ForbiddenKinds = []nostr.Kind{ KindSetupAnnouncement, KindCentralToken, KindCentralRegistration, KindOperatorRegistration, 1776, 1777, }
Functions ¶
func HandleAppleLogin ¶
func HandleAppleLogin(oauthConfig *oauth2.Config) http.HandlerFunc
func HandleGitHubLogin ¶
func HandleGitHubLogin(oauthConfig *oauth2.Config) http.HandlerFunc
func HandleGoogleLogin ¶
func HandleGoogleLogin(oauthConfig *oauth2.Config) http.HandlerFunc
func HandleMicrosoftLogin ¶
func HandleMicrosoftLogin(oauthConfig *oauth2.Config) http.HandlerFunc
Types ¶
type GitHubEmail ¶
type GitHubUser ¶
type GitHubUser struct {
ID int `json:"id"`
Login string `json:"login"`
Email string `json:"email"`
}
func HandleGitHubCallback ¶
type GoogleUser ¶
type GoogleUser struct {
ID string `json:"id"`
Email string `json:"email"`
VerifiedEmail bool `json:"verified_email"`
Picture string `json:"picture"`
}
func HandleGoogleCallback ¶
type MicrosoftUser ¶
type MicrosoftUser struct {
ID string `json:"id"`
Mail string `json:"mail"`
UserPrincipalName string `json:"userPrincipalName"`
}
func HandleMicrosoftCallback ¶
Click to show internal directories.
Click to hide internal directories.